@@ -1,7 +1,7 @@
 package Plack::Middleware::Static;
 use strict;
 use warnings;
-use base qw/Plack::Middleware/;
+use parent qw/Plack::Middleware/;
 use Plack::App::File;
 
 __PACKAGE__->mk_accessors(qw( path root ));
